View source: R/addProcedures.R
| addProcedures | R Documentation |
Add Diagnostic Measurements and Procedure Occurrences to a Cohort
addProcedures(
x,
indexDate = "cohort_start_date",
censorDate = NULL,
window = list(c(-365, -1), c(0, 365)),
labConceptSet = NULL,
imagingConceptSet = NULL,
procedureConceptSet = NULL,
nameStyle = "{metric}_count_{window_name}",
name = NULL
)
x |
A cohort table or cdm_table. |
indexDate |
Date variable in |
censorDate |
Optional date variable in |
window |
A named or unnamed list of 2-element numeric vectors. Default: |
labConceptSet |
Optional concept set / codelist for laboratory tests in |
imagingConceptSet |
Optional concept set / codelist for imaging scans in |
procedureConceptSet |
Optional concept set / codelist for procedures in |
nameStyle |
Column naming pattern. Default: |
name |
Name of the new table in the write schema. If NULL, a temporary table is returned. |
The cohort table x with added procedure and diagnostic metric columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.