View source: R/computeInfusionCohorts.R
| computeInfusionCohorts | R Documentation |
Create Infusion Administration Episode Cohorts
computeInfusionCohorts(
cdm,
name,
conceptSet = NULL,
routeConceptIds = c(4171047L, 4171048L),
collapseGap = 0L
)
cdm |
A |
name |
String specifying the cohort table name in the write schema. |
conceptSet |
Optional concept set / codelist of specific infused drugs. |
routeConceptIds |
Integer vector of OMOP route concept IDs. Default: |
collapseGap |
Maximum gap in days between contiguous administration records to collapse. Default: |
An omopgenerics::cohort_table object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.